==> IrrlichtNetSwig-1.1.0.419.zip: IrrlichtNetSwig/source/StaticStringArray.h <==
#ifndef STATIC_STRING_ARRAY
#define STATIC_STRING_ARRAY

#include"irrlicht.h"

ConstStringArray _sBuiltInMaterialTypeNames()
{
	return ConstStringArray(irr::video::sBuiltInMaterialTypeNames);
}
ConstStringArray _aTextureClampNames()
{
    return ConstStringArray( irr::video::aTextureClampNames);
}
ConstStringArray _sBuiltInVertexTypeNames()
{
    return ConstStringArray( irr::video::sBuiltInVertexTypeNames);
}
ConstStringArray _AutomaticCullingNames()
{
    return ConstStringArray( irr::scene::AutomaticCullingNames);
}
ConstStringArray _GUIAlignmentNames()
{
    return ConstStringArray( irr::gui::GUIAlignmentNames);
}
ConstStringArray _GUIElementTypeNames()
{
    return ConstStringArray( irr::gui::GUIElementTypeNames);
}
ConstStringArray _BoneAnimationModeNames()
{
    return ConstStringArray( irr::scene::BoneAnimationModeNames);
}
ConstStringArray _VERTEX_SHADER_TYPE_NAMES()
{
    return ConstStringArray( irr::video::VERTEX_SHADER_TYPE_NAMES);
}
ConstStringArray _PIXEL_SHADER_TYPE_NAMES()
{
    return ConstStringArray( irr::video::PIXEL_SHADER_TYPE_NAMES);
}
ConstStringArray _GUIButtonStateNames()
{
    return ConstStringArray( irr::gui::GUIButtonStateNames);
}
ConstStringArray _GUISkinTypeNames()
{
    return ConstStringArray( irr::gui::GUISkinTypeNames);
}
ConstStringArray _GUISkinColorNames()
{
    return ConstStringArray( irr::gui::GUISkinColorNames);
}
ConstStringArray _GUISkinSizeNames()
{
    return ConstStringArray( irr::gui::GUISkinSizeNames);
}
ConstStringArray _GUISkinTextNames()
{
    return ConstStringArray( irr::gui::GUISkinTextNames);
}
ConstStringArray _GUISkinIconNames()
{
    return ConstStringArray( irr::gui::GUISkinIconNames);
}
ConstStringArray _GUISkinFontNames()
{
    return ConstStringArray( irr::gui::GUISkinFontNames);
}
ConstStringArray _GUIColumnOrderingNames()
{
    return ConstStringArray( irr::gui::GUIColumnOrderingNames);
}
ConstStringArray _GUIOrderingModeNames()
{
    return ConstStringArray( irr::gui::GUIOrderingModeNames);
}
ConstStringArray _LightTypeNames()
{
    return ConstStringArray( irr::video::LightTypeNames);
}
ConstStringArray _ParticleAffectorTypeNames()
{
    return ConstStringArray( irr::scene::ParticleAffectorTypeNames);
}
ConstStringArray _ParticleEmitterTypeNames()
{
    return ConstStringArray( irr::scene::ParticleEmitterTypeNames);
}

#endif //STATIC_STRING_ARRAY

==> IrrlichtNetSwig-1.2.0.528.zip: IrrlichtNetSwig/source/StaticStringArray.h <==
#ifndef STATIC_STRING_ARRAY
#define STATIC_STRING_ARRAY

#include"irrlicht.h"

ConstStringArray _sBuiltInMaterialTypeNames()
{
	return ConstStringArray(irr::video::sBuiltInMaterialTypeNames);
}
ConstStringArray _aTextureClampNames()
{
    return ConstStringArray( irr::video::aTextureClampNames);
}
ConstStringArray _sBuiltInVertexTypeNames()
{
    return ConstStringArray( irr::video::sBuiltInVertexTypeNames);
}
ConstStringArray _AutomaticCullingNames()
{
    return ConstStringArray( irr::scene::AutomaticCullingNames);
}
ConstStringArray _GUIAlignmentNames()
{
    return ConstStringArray( irr::gui::GUIAlignmentNames);
}
ConstStringArray _GUIElementTypeNames()
{
    return ConstStringArray( irr::gui::GUIElementTypeNames);
}
ConstStringArray _BoneAnimationModeNames()
{
    return ConstStringArray( irr::scene::BoneAnimationModeNames);
}
ConstStringArray _VERTEX_SHADER_TYPE_NAMES()
{
    return ConstStringArray( irr::video::VERTEX_SHADER_TYPE_NAMES);
}
ConstStringArray _PIXEL_SHADER_TYPE_NAMES()
{
    return ConstStringArray( irr::video::PIXEL_SHADER_TYPE_NAMES);
}
ConstStringArray _GUIButtonStateNames()
{
    return ConstStringArray( irr::gui::GUIButtonStateNames);
}
ConstStringArray _GUISkinTypeNames()
{
    return ConstStringArray( irr::gui::GUISkinTypeNames);
}
ConstStringArray _GUISkinColorNames()
{
    return ConstStringArray( irr::gui::GUISkinColorNames);
}
ConstStringArray _GUISkinSizeNames()
{
    return ConstStringArray( irr::gui::GUISkinSizeNames);
}
ConstStringArray _GUISkinTextNames()
{
    return ConstStringArray( irr::gui::GUISkinTextNames);
}
ConstStringArray _GUISkinIconNames()
{
    return ConstStringArray( irr::gui::GUISkinIconNames);
}
ConstStringArray _GUISkinFontNames()
{
    return ConstStringArray( irr::gui::GUISkinFontNames);
}
ConstStringArray _GUIColumnOrderingNames()
{
    return ConstStringArray( irr::gui::GUIColumnOrderingNames);
}
ConstStringArray _GUIOrderingModeNames()
{
    return ConstStringArray( irr::gui::GUIOrderingModeNames);
}
ConstStringArray _LightTypeNames()
{
    return ConstStringArray( irr::video::LightTypeNames);
}
ConstStringArray _ParticleAffectorTypeNames()
{
    return ConstStringArray( irr::scene::ParticleAffectorTypeNames);
}
ConstStringArray _ParticleEmitterTypeNames()
{
    return ConstStringArray( irr::scene::ParticleEmitterTypeNames);
}
ConstStringArray _GEOMETRY_SHADER_TYPE_NAMES()
{
    return ConstStringArray( irr::video::GEOMETRY_SHADER_TYPE_NAMES);
}
ConstStringArray _FogTypeNames()
{
    return ConstStringArray( irr::video::FogTypeNames);
}


#endif //STATIC_STRING_ARRAY
